@@ -30,7 +30,7 @@ cluster_schema = {
 }
 
 global_schema = {
-    "type": "object"
+    "type": ["number", "string", "boolean", "object"]
 }
 
 def validate_feature(data):
